import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import Box from '@mui/material/Box';
import Button from '@mui/material/Button';
import Paper from '@mui/material/Paper';
import TextField from '@mui/material/TextField';
import Typography from '@mui/material/Typography';
import CloudUpload from '@mui/icons-material/CloudUpload';
import { styled } from '@mui/material/styles';
import { EventName } from '../../utils/EventEmitter/constants';
import { EventEmitter } from '../../utils/EventEmitter/EventEmitter';
import IconButton from '@mui/material/IconButton';
import { DeleteOutline } from '@mui/icons-material';
const MAX_FILE_SIZE = 1 * 1024 * 1024; // 1MB in bytes
const VisuallyHiddenInput = styled('input')({
    clip: 'rect(0 0 0 0)',
    clipPath: 'inset(50%)',
    height: 1,
    overflow: 'hidden',
    position: 'absolute',
    bottom: 0,
    left: 0,
    whiteSpace: 'nowrap',
    width: 1,
});
export const BlogForm = ({ name = '', title = '', desc = '', imageUrl = '', resetForm = false, handleFormSubmit, }) => {
    const [formData, setFormData] = useState({
        name: name,
        title: title,
        desc: desc,
    });
    const [imageUrlState, setImageUrlState] = useState(imageUrl);
    const [imageFileState, setImageFileState] = useState(null);
    const [previewImage, setPreviewImage] = useState();
    const [imageRatio, setImageRatio] = useState(null);
    const handleChange = (event) => {
        const { name, value } = event.target;
        setFormData(prevState => ({
            ...prevState,
            [name]: value,
        }));
    };
    useEffect(() => {
        setFormData(prevState => ({
            ...prevState,
            name,
            title,
            desc,
        }));
    }, [name, title, desc]);
    // Reset form when resetForm is true
    useEffect(() => {
        if (resetForm) {
            setImageUrlState('');
            setFormData({ ...formData, title: '', desc: '' });
            setImageFileState(null);
            setPreviewImage(undefined);
            setImageRatio(null);
        }
    }, [resetForm]);
    useEffect(() => {
        // calculate image ratio of image URL
        if (imageUrlState) {
            const img = new Image();
            img.src = imageUrlState;
            img.onload = () => {
                const ratio = (img.width / img.height).toFixed(2);
                setImageRatio(ratio);
            };
        }
    }, [imageUrlState]);
    const handleImageChange = (event) => {
        if (event.target.files && event.target.files[0]) {
            setImageUrlState('');
            const file = event.target.files[0];
            if (file.size > MAX_FILE_SIZE) {
                alert('Image size should not exceed 1MB.');
                return;
            }
            const img = new Image();
            img.src = URL.createObjectURL(file);
            img.onload = () => {
                const ratio = (img.width / img.height).toFixed(2);
                setImageRatio(ratio);
            };
            setImageFileState(file);
            setPreviewImage(URL.createObjectURL(file));
        }
    };
    const handleRemoveImage = () => {
        setImageUrlState('');
        setImageFileState(null);
        setPreviewImage(undefined);
        setImageRatio(null);
        // Reset the file input field to allow reselecting the same file
        const fileInput = document.querySelector('input[type="file"]');
        if (fileInput) {
            fileInput.value = '';
        }
    };
    const handleSubmit = (event) => {
        event.preventDefault();
        const completeData = {
            ...formData,
            image: imageUrlState || imageFileState,
        };
        handleFormSubmit(completeData);
        EventEmitter(EventName.handleFormSubmit, completeData);
    };
    return (_jsx(Box, { sx: {
            p: { xs: 2, sm: 2, md: 4 },
            background: '#f0f4f8',
            borderRadius: '16px',
            margin: 'auto',
        }, children: _jsxs(Paper, { component: "form", onSubmit: handleSubmit, variant: "elevation", elevation: 4, sx: { p: 3 }, children: [_jsx(Typography, { variant: "h4", gutterBottom: true, children: name && desc ? 'Edit Blog Post' : 'Create Blog Post' }), _jsx(TextField, { label: "Your Name", name: "name", value: formData.name, onChange: handleChange, fullWidth: true, margin: "normal", required: true, disabled: true }), _jsx(TextField, { label: "Title of Blog", name: "title", value: formData.title, onChange: e => e.target.value.length <= 50 &&
                        handleChange(e), helperText: `${formData.title.length}/50`, fullWidth: true, margin: "normal", required: true }), _jsx(TextField, { label: "Description of Blog", name: "desc", value: formData.desc, onChange: e => e.target.value.length <= 5000 &&
                        handleChange(e), helperText: `${formData.desc.length}/5000`, fullWidth: true, margin: "normal", required: true, multiline: true, rows: 12 }), _jsxs(Box, { display: "flex", flexDirection: "column", alignItems: "flex-start", width: "100%", mt: 2, children: [_jsx(Typography, { variant: "caption", color: "textSecondary", gutterBottom: true, children: "Recommended image ratio: 1.5" }), _jsxs(Button, { component: "label", variant: "outlined", startIcon: _jsx(CloudUpload, {}), children: [_jsx(Typography, { variant: "caption", fontSize: '0.6rem', children: "Upload image (Max 1MB)" }), _jsx(VisuallyHiddenInput, { type: "file", accept: "image/*", onChange: handleImageChange })] }), imageFileState || imageUrlState ? (_jsxs(Box, { display: "flex", flexDirection: "column", alignItems: "flex-start", mt: 2, children: [_jsxs(Typography, { variant: "caption", color: "textSecondary", children: ["Uploaded image ratio: ", imageRatio] }), _jsxs(Box, { display: 'flex', children: [_jsx(Box, { component: "img", src: imageUrlState || previewImage, alt: "Preview", sx: {
                                                width: 'auto',
                                                height: '100px',
                                                borderRadius: 2,
                                                boxShadow: 1,
                                                mr: 1,
                                            } }), _jsx(IconButton, { onClick: handleRemoveImage, color: "error", sx: { height: '40px', width: '40px' }, children: _jsx(DeleteOutline, {}) })] })] })) : (_jsx(Typography, { fontStyle: "italic", variant: "caption", children: "Optional" })), name.toLowerCase().includes('anonymous') && (_jsxs(Typography, { variant: "caption", color: "textSecondary", fontStyle: "italic", children: [_jsx("br", {}), _jsx("br", {}), "(Note: Anyone has update and delete permissions for anonymous posts.)"] })), _jsx(Button, { type: "submit", variant: "contained", color: "primary", fullWidth: true, sx: { mt: 2 }, children: name && desc ? 'Update Post' : 'Create Post' })] })] }) }));
};
